<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eo" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <location filename="../src/alert.cpp" line="236"/>
        <source>Close (%1)</source>
        <translation>Fermi (%1)</translation>
    </message>
    <message>
        <location filename="../src/alert.cpp" line="177"/>
        <source>Collapse</source>
        <translation>Maletendi</translation>
    </message>
    <message>
        <location filename="../src/alert.cpp" line="181"/>
        <source>Expand</source>
        <translation>Etendi</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <location filename="../src/alert_layer.cpp" line="37"/>
        <source>Dismiss Alert</source>
        <translation>Forsendi Averton</translation>
    </message>
    <message>
        <location filename="../src/alert_layer.cpp" line="38"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <location filename="../src/daily_progress.cpp" line="503"/>
        <source>%1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%1% de %Ln minuto</numerusform>
            <numerusform>%1% de %Ln minutoj</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/daily_progress.cpp" line="505"/>
        <source>%1% of %Ln word(s)</source>
        <translation>
            <numerusform>%1% de %Ln vorto</numerusform>
            <numerusform>%1% de %Ln vortoj</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/daily_progress.cpp" line="507"/>
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln vorto</numerusform>
            <numerusform>%Ln vortoj</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/daily_progress.cpp" line="509"/>
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minuto</numerusform>
            <numerusform>%Ln minutoj</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/daily_progress.cpp" line="511"/>
        <source>0%</source>
        <translation>0%</translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <location filename="../src/daily_progress_dialog.cpp" line="146"/>
        <source>Daily Progress</source>
        <translation>Ĉiutaga Progreso</translation>
    </message>
    <message>
        <location filename="../src/daily_progress_dialog.cpp" line="282"/>
        <source>Longest streak</source>
        <translation>Plej longa serio</translation>
    </message>
    <message>
        <location filename="../src/daily_progress_dialog.cpp" line="285"/>
        <source>Current streak</source>
        <translation>Aktuala serio</translation>
    </message>
    <message>
        <location filename="../src/daily_progress_dialog.cpp" line="298"/>
        <source>N/A</source>
        <translation>N-A</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/daily_progress_dialog.cpp" line="303"/>
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n tago</numerusform>
            <numerusform>%n tagoj</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/daily_progress_dialog.cpp" line="304"/>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <location filename="../src/daily_progress_label.cpp" line="30"/>
        <location filename="../src/daily_progress_label.cpp" line="47"/>
        <source>%1% of daily goal</source>
        <translation>%1% de ĉiutaga celo</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <location filename="../src/spelling/dictionary_dialog.cpp" line="36"/>
        <source>Set Language</source>
        <translation>Agordi Lingvon</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <location filename="../src/document.cpp" line="425"/>
        <source>(Untitled %1)</source>
        <translation>(Sentitole %1)</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="428"/>
        <source>%1 (Read-Only)</source>
        <translation>%1 (Nurlegebla)</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="492"/>
        <location filename="../src/document.cpp" line="517"/>
        <location filename="../src/document.cpp" line="553"/>
        <location filename="../src/document.cpp" line="559"/>
        <source>Sorry</source>
        <translation>Pardonu</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="492"/>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>Ne eblis konservi &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="507"/>
        <source>Save File As</source>
        <translation>Konservi Dosieron Kiel</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="517"/>
        <location filename="../src/document.cpp" line="553"/>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>Ne eblis anstataŭigi &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="546"/>
        <source>Rename File</source>
        <translation>Renomi Dosieron</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="559"/>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>Ne eblis renomi &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="585"/>
        <source>Reload File?</source>
        <translation>Reŝargi la Dosieron?</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="586"/>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Reŝargi la dosieron &apos;%1&apos; el disko?</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="587"/>
        <source>All unsaved changes will be lost.</source>
        <translation>Ĉiuj nekonservitaj ŝanĝoj perdiĝos.</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="589"/>
        <source>Reload</source>
        <translation>Reŝargi</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="1321"/>
        <source>Untitled %1</source>
        <translation>Sentitole %1</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="1375"/>
        <source>Question</source>
        <translation>Demando</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="1376"/>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Savi kiel plata teksto ne konservos ĉiun tekstaranĝon. Ne konservi tekstaranĝon?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <location filename="../src/document_watcher.cpp" line="191"/>
        <source>File Changed</source>
        <translation>Dosiero Ŝanĝiĝis</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="192"/>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>La dosiero &apos;%1&apos; ŝanĝiĝis de alia programaro.</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="193"/>
        <source>Do you want to reload the file?</source>
        <translation>Ĉu vi volas reŝargi la dosieron?</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="195"/>
        <source>Reload</source>
        <translation>Reŝargi</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="200"/>
        <source>Ignore</source>
        <translation>Malatenti</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="211"/>
        <source>File Deleted</source>
        <translation>Dosiero Foriĝis</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="212"/>
        <source>The file %1 was deleted by another program.</source>
        <translation>La dosiero %1 foriĝis de alia programaro.</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="213"/>
        <source>Do you want to save or close the file?</source>
        <translation>Ĉu vi volas konservi aŭ fermi la dosieron?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <location filename="../src/fileformats/docx_reader.cpp" line="94"/>
        <source>Unable to open archive.</source>
        <translation>Ne eblis malfermi arĥivon.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <location filename="../src/find_dialog.cpp" line="47"/>
        <source>Search for:</source>
        <translation>Serĉi por:</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="49"/>
        <source>Replace with:</source>
        <translation>Anstataŭigi kun:</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="53"/>
        <source>Ignore case</source>
        <translation>Malatenti usklon</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="54"/>
        <source>Whole words only</source>
        <translation>Nur tutaj vortoj</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="55"/>
        <source>Regular expressions</source>
        <translation>Regulesprimoj</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="58"/>
        <source>Search up</source>
        <translation>Serĉi supren</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="59"/>
        <source>Search down</source>
        <translation>Serĉi malsupren</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="66"/>
        <source>&amp;Find</source>
        <translation>Trovi</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="70"/>
        <source>&amp;Replace</source>
        <translation>Anstataŭigi</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="74"/>
        <source>Replace &amp;All</source>
        <translation>Anstataŭigi Ĉiujn</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="151"/>
        <source>Find</source>
        <translation>Trovi</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="159"/>
        <source>Replace</source>
        <translation>Anstataŭigi</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/find_dialog.cpp" line="275"/>
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Anstataŭigi %n aperon?</numerusform>
            <numerusform>Anstataŭigi %n aperojn?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="275"/>
        <source>Question</source>
        <translation>Demando</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="279"/>
        <location filename="../src/find_dialog.cpp" line="354"/>
        <source>Sorry</source>
        <translation>Pardonu</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="279"/>
        <location filename="../src/find_dialog.cpp" line="354"/>
        <source>Phrase not found.</source>
        <translation>Frazero ne troviĝis.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="71"/>
        <source>OpenDocument Text</source>
        <translation>OpenDocument Teksto</translation>
    </message>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="73"/>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="75"/>
        <source>Rich Text Format</source>
        <translation>Rich Text Format</translation>
    </message>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="77"/>
        <source>Plain Text</source>
        <translation>Plata Teksto</translation>
    </message>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="92"/>
        <source>All Files</source>
        <translation>Ĉiuj Dosieroj</translation>
    </message>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="106"/>
        <source>All Supported Files</source>
        <translation>Ĉiuj Subtenataj Dosieroj</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <location filename="../src/spelling/highlighter.cpp" line="54"/>
        <source>Add</source>
        <translation>Aldoni</translation>
    </message>
    <message>
        <location filename="../src/spelling/highlighter.cpp" line="55"/>
        <source>Check Spelling...</source>
        <translation>Kontroli Literumadon...</translation>
    </message>
    <message>
        <location filename="../src/spelling/highlighter.cpp" line="129"/>
        <source>(No suggestions found)</source>
        <translation>(Ne sugestoj troviĝis)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <location filename="../src/image_button.cpp" line="100"/>
        <source>Open Image</source>
        <translation>Malfermi Bildon</translation>
    </message>
    <message>
        <location filename="../src/image_button.cpp" line="100"/>
        <source>Images(%1)</source>
        <translation>Bildoj(%1)</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="51"/>
        <source>Select application language:</source>
        <translation>Elekti lingvon de aplikaĵo:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="54"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Lingvo de Sistemo&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="189"/>
        <source>Note</source>
        <translation>Noto</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="189"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Bonvolu relanĉi ĉi tiun aplikaĵon por la lingva ŝanĝo efiki.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <location filename="../src/fileformats/odt_reader.cpp" line="68"/>
        <source>Unable to open archive.</source>
        <translation>Ne eblis malfermi arĥivon.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="109"/>
        <source>Preferences</source>
        <translation>Agordoj</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="112"/>
        <source>General</source>
        <translation>Ĝenerale</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="114"/>
        <source>Statistics</source>
        <translation>Statistiko</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="116"/>
        <source>Toolbar</source>
        <translation>Ilobreto</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="115"/>
        <source>Spell Checking</source>
        <translation>Literumada Kontrolo</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="453"/>
        <source>Select Dictionary</source>
        <translation>Elekti Vortaron</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="467"/>
        <location filename="../src/preferences_dialog.cpp" line="570"/>
        <source>Sorry</source>
        <translation>Pardonu</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="467"/>
        <source>Unable to open archive.</source>
        <translation>Ne eblis malfermi arĥivon.</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="570"/>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>La arĥivo ne enhavas uzeblan vortaron.</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="256"/>
        <location filename="../src/preferences_dialog.cpp" line="395"/>
        <location filename="../src/preferences_dialog.cpp" line="558"/>
        <source>Question</source>
        <translation>Demandon</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="117"/>
        <source>Shortcuts</source>
        <translation>Fulmoklavoj</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="257"/>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Unu aŭ pluraj fulmoklavoj konfliktas. Ĉu vi volas daŭri?</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="558"/>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>La vortaro &quot;%1&quot; jam ekzistas. Ĉu vi volas anstataŭigi ĝin?</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="113"/>
        <source>Daily Goal</source>
        <translation>Ĉiutaga Celo</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="793"/>
        <source>None</source>
        <translation>Nenio</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="795"/>
        <source>Minutes:</source>
        <translation>Minutoj:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="802"/>
        <location filename="../src/preferences_dialog.cpp" line="912"/>
        <source>Words:</source>
        <translation>Vortoj:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="705"/>
        <source>Editing</source>
        <translation>Redaktado</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="707"/>
        <source>Always vertically center</source>
        <translation>Ĉiam vertikale centri</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="708"/>
        <source>Block insertion cursor</source>
        <translation>Bloka enmeta kursoro</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="709"/>
        <source>Smooth fonts</source>
        <translation>Glataj tajparoj</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="710"/>
        <source>Typewriter sounds</source>
        <translation>Skribmaŝinaj sonoj</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="712"/>
        <source>Smart quotes:</source>
        <translation>Inteligentaj citiloj:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="719"/>
        <source>Double</source>
        <translation>Duoble</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="720"/>
        <source>Single</source>
        <translation>Unuoble</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="741"/>
        <source>Scenes</source>
        <translation>Scenoj</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="748"/>
        <source>Divider:</source>
        <translation>Dividanto:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="751"/>
        <source>Saving</source>
        <translation>Konservante</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="753"/>
        <source>Automatically save changes</source>
        <translation>Aŭtomate konservi ŝanĝojn</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="754"/>
        <source>Remember cursor position</source>
        <translation>Memori kursoran pozicion</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="872"/>
        <source>Word count</source>
        <translation>Vortnombrado</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="873"/>
        <source>Page count</source>
        <translation>Paĝnombrado</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="874"/>
        <source>Paragraph count</source>
        <translation>Alinenombrado</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="875"/>
        <source>Character count</source>
        <translation>Signonombrado</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="898"/>
        <source>Characters:</source>
        <translation>Signoj:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="905"/>
        <source>Paragraphs:</source>
        <translation>Alineoj</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="884"/>
        <source>Word Count Algorithm</source>
        <translation>Vortnombrada Algoritmo</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="396"/>
        <source>Reset daily progress for today to zero?</source>
        <translation>Rekomencigi ĉiutagan progreson por hodiaŭ?</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="755"/>
        <source>Write byte order mark in plain text files</source>
        <translation>Skribi bajtordo-marko en platatekstajn dosierojn</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="757"/>
        <source>Default format:</source>
        <translation>Defaŭlta dosierformo:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="818"/>
        <source>Reset Today</source>
        <translation>Rekomencigi Hodiaŭ</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="831"/>
        <source>History</source>
        <translation>Historio</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="833"/>
        <source>Remember history</source>
        <translation>Memori historion</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="836"/>
        <source>Show streaks</source>
        <translation>Montri seriojn</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="851"/>
        <source>Minimum progress for streaks:</source>
        <translation>Minimuma progreso por serioj:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="886"/>
        <source>Detect word boundaries</source>
        <translation>Detekti vortlimojn</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="887"/>
        <source>Divide character count by six</source>
        <translation>Dividi signonombradon per ses</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="888"/>
        <source>Count each letter as a word</source>
        <translation>Kompti ĉiun literon kiel vorto</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="896"/>
        <source>Page Count Algorithm</source>
        <translation>Paĝnombrada Algoritmo</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1039"/>
        <source>Style</source>
        <translation>Stilo</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1042"/>
        <source>Icons Only</source>
        <translation>Nur Bildsimboloj</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1043"/>
        <source>Text Only</source>
        <translation>Nur Teksto</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1044"/>
        <source>Text Alongside Icons</source>
        <translation>Teksto Flanke de Bildsimboloj</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1045"/>
        <source>Text Under Icons</source>
        <translation>Teksto Malsupre de Bildsignoj</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1049"/>
        <source>Text Position:</source>
        <translation>Pozicio de Teksto</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1052"/>
        <source>Actions</source>
        <translation>Agoj</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1068"/>
        <source>Move Up</source>
        <translation>Movi Supren</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1070"/>
        <source>Move Down</source>
        <translation>Movi Malsupren</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1072"/>
        <source>Add Separator</source>
        <translation>Aldoni Apartigilon</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1106"/>
        <source>Command</source>
        <translation>Komando</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1106"/>
        <source>Shortcut</source>
        <translation>Fulmoklavo</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1106"/>
        <source>Action</source>
        <translation>Ago</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="959"/>
        <source>Check spelling as you type</source>
        <translation>Kontroli literumadon dum vi tajpas</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="960"/>
        <source>Ignore words in UPPERCASE</source>
        <translation>Malatenti vortojn da MAJUSKLOJ</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="961"/>
        <source>Ignore words with numbers</source>
        <translation>Malatenti vortojn kun numeroj</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="974"/>
        <source>Language</source>
        <translation>Lingvo</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="978"/>
        <location filename="../src/preferences_dialog.cpp" line="999"/>
        <source>Add</source>
        <translation>Aldoni</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1011"/>
        <source>Remove</source>
        <translation>Forigi</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="994"/>
        <source>Personal Dictionary</source>
        <translation>Persona Vortaro</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <location filename="../src/fileformats/rtf_reader.cpp" line="209"/>
        <location filename="../src/fileformats/rtf_reader.cpp" line="213"/>
        <source>Not a supported RTF file.</source>
        <translation>Ne subtenata RTF dosiero.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <location filename="../src/fileformats/rtf_tokenizer.cpp" line="151"/>
        <source>Unexpectedly reached end of file.</source>
        <translation>Neatendite atingis dosierfinon.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <location filename="../src/scene_list.cpp" line="89"/>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Malsupren</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="94"/>
        <source>Move Scenes Up</source>
        <translation>Movi Scenojn Supren</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="95"/>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Supren</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="115"/>
        <source>Toggle Scene List</source>
        <translation>Baskuligi Liston da Scenoj</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="116"/>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="399"/>
        <source>Show scene list (%1)</source>
        <translation>Montri liston da scenoj (%1)</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="400"/>
        <source>Hide scene list (%1)</source>
        <translation>Kaŝi liston da scenoj (%1)</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="147"/>
        <source>Filter</source>
        <translation>Filtri</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="88"/>
        <source>Move Scenes Down</source>
        <translation>Movi Scenojn Malsupren</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="155"/>
        <source>Resize scene list</source>
        <translation>Regrandigi liston da scenoj</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <location filename="../src/session.cpp" line="43"/>
        <location filename="../src/session_manager.cpp" line="57"/>
        <location filename="../src/session_manager.cpp" line="428"/>
        <location filename="../src/session_manager.cpp" line="451"/>
        <location filename="../src/session_manager.cpp" line="460"/>
        <location filename="../src/session_manager.cpp" line="461"/>
        <source>Default</source>
        <translation>Defaŭlto</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <location filename="../src/session_manager.cpp" line="52"/>
        <source>Manage Sessions</source>
        <translation>Administri Seancojn</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="83"/>
        <source>S&amp;essions</source>
        <translation>Seancojn</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="97"/>
        <source>New</source>
        <translation>Nova</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="100"/>
        <source>Duplicate</source>
        <translation>Duobligi</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="103"/>
        <source>Rename</source>
        <translation>Renomi</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="106"/>
        <source>Delete</source>
        <translation>Forigi</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="109"/>
        <source>Switch To</source>
        <translation>Ŝanĝi Al</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="220"/>
        <source>New Session</source>
        <translation>Nova Seanco</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="279"/>
        <source>Duplicate Session</source>
        <translation>Duobligi Seancon</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="324"/>
        <source>Rename Session</source>
        <translation>Renomi Seancon</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="351"/>
        <source>Question</source>
        <translation>Demando</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="351"/>
        <source>Delete selected session?</source>
        <translation>Forigi elektitan seancon?</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="423"/>
        <source>Session name:</source>
        <translation>Seanca nomo:</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="431"/>
        <source>Sorry</source>
        <translation>Pardonu</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="431"/>
        <source>The requested session name is already in use.</source>
        <translation>La petita seanca nomo estas jam uzata.</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="487"/>
        <source>&amp;New...</source>
        <translation>Nova...</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="487"/>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="488"/>
        <source>&amp;Manage...</source>
        <translation>Administri</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="488"/>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../src/shortcut_edit.cpp" line="126"/>
        <source>Clear</source>
        <translation>Vakigi</translation>
    </message>
    <message>
        <location filename="../src/shortcut_edit.cpp" line="129"/>
        <source>Reset to Default</source>
        <translation>Rekomencigi Defaŭlten</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1149"/>
        <location filename="../src/symbols_dialog.cpp" line="219"/>
        <source>Shortcut:</source>
        <translation>Fulmoklavo:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <location filename="../src/smart_quotes.cpp" line="150"/>
        <source>Replacing quotation marks...</source>
        <translation>Anstataŭigante citilojn...</translation>
    </message>
    <message>
        <location filename="../src/smart_quotes.cpp" line="151"/>
        <source>Please Wait</source>
        <translation>Bonvolu Atendi</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="134"/>
        <source>Check Spelling</source>
        <translation>Kontroli Literumadon</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="142"/>
        <source>&amp;Add</source>
        <translation>Aldoni</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="145"/>
        <source>&amp;Ignore</source>
        <translation>Malatenti</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="148"/>
        <source>I&amp;gnore All</source>
        <translation>Malatenti Ĉiujn</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="153"/>
        <source>&amp;Change</source>
        <translation>Ŝanĝi</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="156"/>
        <source>C&amp;hange All</source>
        <translation>Ŝanĝi Ĉiujn</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="171"/>
        <source>Not in dictionary:</source>
        <translation>Ne en vortaro:</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="179"/>
        <source>Change to:</source>
        <translation>Ŝanĝi al:</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="195"/>
        <source>Checking spelling...</source>
        <translation>Kontrolante literumadon...</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="195"/>
        <source>Cancel</source>
        <translation>Nuligi</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="196"/>
        <source>Please wait</source>
        <translation>Bonvolu atendi</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="223"/>
        <source>Continue checking at beginning of file?</source>
        <translation>Daŭri kontroli dekomence?</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="282"/>
        <source>Spell check complete.</source>
        <translation>Literumada kontrolo finfaris.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="96"/>
        <source>Symbols</source>
        <translation>Simboloj</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="103"/>
        <source>Recently used symbols</source>
        <translation>Lastatempe uzitaj simboloj</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="133"/>
        <source>All symbols</source>
        <translation>Ĉiuj simboloj</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="195"/>
        <source>Details</source>
        <translation>Detaloj</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="221"/>
        <source>Name:</source>
        <translation>Nomo:</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="231"/>
        <source>Insert</source>
        <translation>Enmeto</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <location filename="../src/symbols_model.cpp" line="107"/>
        <source>Blocks</source>
        <translation>Blokoj</translation>
    </message>
    <message>
        <location filename="../src/symbols_model.cpp" line="107"/>
        <source>Scripts</source>
        <translation>Skriboj</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <location filename="../src/theme.cpp" line="103"/>
        <source>Untitled %1</source>
        <translation>Sentitole %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <location filename="../src/theme_dialog.cpp" line="103"/>
        <source>Name:</source>
        <translation>Nomo:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <source>No Image</source>
        <translation>Neniu Bildo</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <source>Tiled</source>
        <translation>Kahelita</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <location filename="../src/theme_dialog.cpp" line="196"/>
        <source>Centered</source>
        <translation>Centrita</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <location filename="../src/theme_dialog.cpp" line="196"/>
        <source>Stretched</source>
        <translation>Streĉita</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <source>Scaled</source>
        <translation>Skalita</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <source>Zoomed</source>
        <translation>Zomita</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="211"/>
        <source>Opacity:</source>
        <translation>Opakeco:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="212"/>
        <source>Position:</source>
        <translation>Pozicio:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="213"/>
        <source>Width:</source>
        <translation>Larĝo:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="217"/>
        <source>Round Text Background Corners</source>
        <translation>Rondaj Tekstfonaj Anguloj</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="231"/>
        <location filename="../src/theme_dialog.cpp" line="249"/>
        <location filename="../src/theme_dialog.cpp" line="279"/>
        <source>Radius:</source>
        <translation>Duondiametro:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="235"/>
        <source>Blur Text Background</source>
        <translation>Malfokusi Tekstfonon</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="253"/>
        <source>Text Background Drop Shadow</source>
        <translation>Tekstfona Ĵetita Ombro</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="280"/>
        <source>Vertical Offset:</source>
        <translation>Vertikala Deŝovo:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="284"/>
        <source>Margins</source>
        <translation>Marĝenoj</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="302"/>
        <source>Window:</source>
        <translation>Fenestro:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="303"/>
        <source>Page:</source>
        <translation>Paĝo:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="361"/>
        <source>Indent first line</source>
        <translation>Krei krommarĝenon sur la unua lineo</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="368"/>
        <source>Above:</source>
        <translation>Supre:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="369"/>
        <source>Below:</source>
        <translation>Malsupre:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="160"/>
        <source>Remove</source>
        <translation>Forigi</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="93"/>
        <source>Edit Theme</source>
        <translation>Redakti Etoson</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="150"/>
        <source>Window Background</source>
        <translation>Fenestra Fono</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="178"/>
        <location filename="../src/theme_dialog.cpp" line="332"/>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="144"/>
        <location filename="../src/theme_dialog.cpp" line="176"/>
        <location filename="../src/theme_dialog.cpp" line="210"/>
        <location filename="../src/theme_dialog.cpp" line="278"/>
        <source>Color:</source>
        <translation>Koloro:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="177"/>
        <source>Image:</source>
        <translation>Bildo:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="202"/>
        <location filename="../src/theme_dialog.cpp" line="224"/>
        <location filename="../src/theme_dialog.cpp" line="242"/>
        <location filename="../src/theme_dialog.cpp" line="264"/>
        <location filename="../src/theme_dialog.cpp" line="271"/>
        <location filename="../src/theme_dialog.cpp" line="288"/>
        <location filename="../src/theme_dialog.cpp" line="295"/>
        <location filename="../src/theme_dialog.cpp" line="344"/>
        <location filename="../src/theme_dialog.cpp" line="350"/>
        <location filename="../src/theme_dialog.cpp" line="356"/>
        <source> pixels</source>
        <translation>bilderoj</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="196"/>
        <source>Left</source>
        <translation>Maldekstre</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="182"/>
        <source>Text Background</source>
        <translation>Tekstfono</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="196"/>
        <source>Right</source>
        <translation>Dekstre</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="116"/>
        <source>Text</source>
        <translation>Teksto</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="145"/>
        <source>Font:</source>
        <translation>Tajparo:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="146"/>
        <source>Misspelled:</source>
        <translation>Misortografiita:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="307"/>
        <source>Line Spacing</source>
        <translation>Interlinea Distanco</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="311"/>
        <source>Single</source>
        <translation>Unuoble</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="311"/>
        <source>1.5 Lines</source>
        <translation>1.5 Lineoj</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="311"/>
        <source>Double</source>
        <translation>Duoble</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="311"/>
        <source>Proportional</source>
        <translation>Proporcie</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="333"/>
        <source>Height:</source>
        <translation>Alto:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="341"/>
        <source>Paragraph Spacing</source>
        <translation>Interalinea Distanco</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="367"/>
        <source>Tab Width:</source>
        <translation>Larĝo de Tabo:</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="253"/>
        <source>New Theme</source>
        <translation>Nova Etoso</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <location filename="../src/theme_manager.cpp" line="78"/>
        <source>Themes</source>
        <translation>Etosoj</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="92"/>
        <source>Default</source>
        <translation>Defaŭlto</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="107"/>
        <source>Gentle Blues</source>
        <translation>Mola Bluso</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="108"/>
        <source>Old School</source>
        <translation>Malnova Lernejo</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="109"/>
        <source>Space Dreams</source>
        <translation>Kosmaj Sonĝoj</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="110"/>
        <source>Writing Desk</source>
        <translation>Skribtablo</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="113"/>
        <location filename="../src/theme_manager.cpp" line="174"/>
        <source>New</source>
        <translation>Nova</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="117"/>
        <location filename="../src/theme_manager.cpp" line="178"/>
        <source>Duplicate</source>
        <translation>Duobligi</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="131"/>
        <source>Custom</source>
        <translation>Propra</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="183"/>
        <source>Edit</source>
        <translation>Redakti</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="188"/>
        <source>Delete</source>
        <translation>Forigi</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="193"/>
        <source>Import</source>
        <translation>Enporti</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="197"/>
        <source>Export</source>
        <translation>Elporti</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="311"/>
        <source>Question</source>
        <translation>Demando</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="311"/>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Forigi etoson &apos;%1&apos;?</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="339"/>
        <location filename="../src/theme_manager.cpp" line="416"/>
        <source>Themes (%1)</source>
        <translation>Etosoj (%1)</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="339"/>
        <source>Import Theme</source>
        <translation>Elporti Etoson</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="416"/>
        <source>Export Theme</source>
        <translation>Elporti Etoson</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <location filename="../src/timer.cpp" line="255"/>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="340"/>
        <source>Question</source>
        <translation>Demando</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="340"/>
        <source>Delete timer?</source>
        <translation>Forigi tempmezurilon?</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="355"/>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Vortoj:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="356"/>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Paĝoj:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="357"/>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Alineoj:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="358"/>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Signoj:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="402"/>
        <source>Set Delay</source>
        <translation>Agordi Prokraston</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="403"/>
        <source>Set Time</source>
        <translation>Agordi Tempon</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="406"/>
        <source>Delay:</source>
        <translation>Prokrasto:</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="409"/>
        <source>Time:</source>
        <translation>Tempo:</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="418"/>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="431"/>
        <source>Alarm</source>
        <translation>Alarmo</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="444"/>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="448"/>
        <source>Memo:</source>
        <translation>Noto:</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="459"/>
        <source>Edit</source>
        <translation>Redakti</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="461"/>
        <source>Delete</source>
        <translation>Forigi</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <location filename="../src/timer_display.cpp" line="150"/>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <location filename="../src/timer_display.cpp" line="160"/>
        <source>No timers running</source>
        <translation>Neniu funkcianta tempmezurilo</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <location filename="../src/timer_manager.cpp" line="46"/>
        <source>Timers</source>
        <translation>Tempmezuriloj</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="78"/>
        <source>New</source>
        <translation>Nova</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="83"/>
        <source>Recent</source>
        <translation>Lastatempe</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="123"/>
        <source>Question</source>
        <translation>Demando</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="123"/>
        <source>Cancel editing timers?</source>
        <translation>Rezigni redakton de tempmezuriloj?</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="316"/>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="323"/>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/window.cpp" line="300"/>
        <source>Loading themes</source>
        <translation>Ŝargante etosojn</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1146"/>
        <source>Loading sounds</source>
        <translation>Ŝargante sonojn</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="309"/>
        <location filename="../src/window.cpp" line="1065"/>
        <source>Untitled</source>
        <translation>Sentitole</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="682"/>
        <source>Open File</source>
        <translation>Malfermi Dosieron</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="864"/>
        <source>About FocusWriter</source>
        <translation>Pri FocusWriter</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="867"/>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="868"/>
        <source>A simple fullscreen word processor</source>
        <translation>Simpla tutekrana tekstoprilaborilo</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="869"/>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Kopirajto &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="870"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Eldonita per la &lt;a href=%1&gt;GPL 3&lt;/a&gt; permesilo</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="871"/>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Uzas bildsimbolojn de la &lt;a href=%1&gt;Oxygen&lt;/a&gt; bildsimbola etoso</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="872"/>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Uzata per la &lt;a href=%1&gt;LGPL 3&lt;/a&gt; permesilo</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="174"/>
        <location filename="../src/window.cpp" line="928"/>
        <source>Characters: %L1 / %L2</source>
        <translation>Signoj: %L1 / %L2</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="172"/>
        <location filename="../src/window.cpp" line="929"/>
        <source>Pages: %L1</source>
        <translation>Paĝoj: %L1</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="173"/>
        <location filename="../src/window.cpp" line="930"/>
        <source>Paragraphs: %L1</source>
        <translation>Alineoj: %L1</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="171"/>
        <location filename="../src/window.cpp" line="931"/>
        <source>Words: %L1</source>
        <translation>Vortoj: %1</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="602"/>
        <location filename="../src/window.cpp" line="1020"/>
        <source>Opening %1</source>
        <translation>Malfermante %1</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="332"/>
        <source>(Untitled %1)</source>
        <translation>(Sentitole %1)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="207"/>
        <source>List all documents</source>
        <translation>Listi ĉiujn dokumentojn</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="210"/>
        <source>Switch to Next Document</source>
        <translation>Ŝanĝi al Sekva Dokumento</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="216"/>
        <source>Switch to Previous Document</source>
        <translation>Ŝanĝi al Antaŭa Dokumento</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="222"/>
        <source>Switch to First Document</source>
        <translation>Ŝanĝi al Unua Dokumento</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="228"/>
        <source>Switch to Last Document</source>
        <translation>Ŝanĝi al Lasta Dokumento</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="236"/>
        <source>Switch to Document %1</source>
        <translation>Ŝanĝi al Dokumento %1</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="296"/>
        <source>Loading settings</source>
        <translation>Ŝargante agordojn</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="318"/>
        <source>Emergency cache is not writable.</source>
        <translation>Kriza kaŝmemoro ne skribeblas.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="338"/>
        <location filename="../src/window.cpp" line="1034"/>
        <source>Warning</source>
        <translation>Averto</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="339"/>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter ne malŝatis pure.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="340"/>
        <source>Restore from the emergency cache?</source>
        <translation>Restaŭri de la kriza kaŝmemoro?</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="467"/>
        <source>Some files could not be opened.</source>
        <translation>Ne eblis malfermi kelkajn dosierojn.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="470"/>
        <source>Some files were opened Read-Only.</source>
        <translation>Kelkaj dosieroj malfermis nurlegeble.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1035"/>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; estas plinova ol la kaŝmemorita kopio.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1036"/>
        <source>Overwrite newer file?</source>
        <translation>Anstataŭigi la novan dosieron?</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1121"/>
        <source>Save Changes?</source>
        <translation>Konservi Ŝanĝojn?</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1122"/>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Konservi ŝanĝojn en la dosieron &apos;%1&apos; antaŭ fermi?</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1123"/>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Viaj ŝanĝoj estos perditaj, se vi ne konservas ilin.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1153"/>
        <source>Unable to load typewriter sounds.</source>
        <translation>Ne eblis ŝargi skribmaŝinajn sonojn.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1154"/>
        <source>Please make sure that SDL_mixer is installed.</source>
        <translation>Bonvolu certiĝi ke SDL_mixer estas instalita.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1290"/>
        <source>&amp;File</source>
        <translation>Dosiero</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1291"/>
        <source>&amp;New</source>
        <translation>Nova</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1292"/>
        <source>&amp;Open...</source>
        <translation>Malfermi...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1293"/>
        <source>Reloa&amp;d</source>
        <translation>Reŝargi</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1295"/>
        <source>&amp;Save</source>
        <translation>Konservi</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1297"/>
        <source>Save &amp;As...</source>
        <translation>Konservi Kiel</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1298"/>
        <source>&amp;Rename...</source>
        <translation>Renomi...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1300"/>
        <source>Save A&amp;ll</source>
        <translation>Konservi Ĉiujn</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1303"/>
        <source>Manage Sessions</source>
        <translation>Administri Seancojn</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1305"/>
        <source>New Session</source>
        <translation>Nova Seanco</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1308"/>
        <source>&amp;Print...</source>
        <translation>Presi..</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1310"/>
        <source>&amp;Close</source>
        <translation>Fermi...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1311"/>
        <source>&amp;Quit</source>
        <translation>Ĉesi</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1311"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1315"/>
        <source>&amp;Edit</source>
        <translation>Redakti</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1316"/>
        <source>&amp;Undo</source>
        <translation>Malfari</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1319"/>
        <source>&amp;Redo</source>
        <translation>Refari</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1323"/>
        <source>Cu&amp;t</source>
        <translation>Etondi</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1326"/>
        <source>&amp;Copy</source>
        <translation>Kopii</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1329"/>
        <source>&amp;Paste</source>
        <translation>Enmeti</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1330"/>
        <source>Paste &amp;Unformatted</source>
        <translation>Enmeti Senaranĝe</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1330"/>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1332"/>
        <source>Select &amp;All</source>
        <translation>Elekti Ĉion</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1333"/>
        <source>Select &amp;Scene</source>
        <translation>Elekti Scenon</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1333"/>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1336"/>
        <source>Fo&amp;rmat</source>
        <translation>Aranĝo</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1338"/>
        <source>&amp;Bold</source>
        <translation>Grasa</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1340"/>
        <source>&amp;Italic</source>
        <translation>Kursiva</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1342"/>
        <source>&amp;Underline</source>
        <translation>Substreki</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1344"/>
        <source>Stri&amp;kethrough</source>
        <translation>Trastreki</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1344"/>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1346"/>
        <source>Sup&amp;erscript</source>
        <translation>Supra indico</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1346"/>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1348"/>
        <source>&amp;Subscript</source>
        <translation>Suba indico</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1348"/>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1352"/>
        <source>Align &amp;Left</source>
        <translation>Ĝisrandigi Maldekstren</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1352"/>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1354"/>
        <source>Align &amp;Center</source>
        <translation>Centrigi</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1354"/>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1356"/>
        <source>Align &amp;Right</source>
        <translation>Ĝisrandigi Dekstren</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1356"/>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1358"/>
        <source>Align &amp;Justify</source>
        <translation>Ĝisrandigi</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1358"/>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1368"/>
        <source>&amp;Decrease Indent</source>
        <translation>Malgrandigi Krommarĝenon</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1368"/>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1369"/>
        <source>I&amp;ncrease Indent</source>
        <translation>Grandigi Krommarĝenon</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1369"/>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1372"/>
        <source>Le&amp;ft to Right Block</source>
        <translation>Demaldekstra Bloko</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1374"/>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Dedekstra Bloko</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1382"/>
        <source>&amp;Tools</source>
        <translation>Iloj</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1383"/>
        <source>&amp;Find...</source>
        <translation>Trovi...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1384"/>
        <source>Find &amp;Next</source>
        <translation>Trovi Sekve</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1387"/>
        <source>Find Pre&amp;vious</source>
        <translation>Trovi Antaŭe</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1390"/>
        <source>&amp;Replace...</source>
        <translation>Antaŭigi...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1390"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1392"/>
        <source>Smart &amp;Quotes</source>
        <translation>Inteligentaj Citiloj</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1393"/>
        <source>Update &amp;Document</source>
        <translation>Ĝisdatigi Dokumenton</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1396"/>
        <source>Update &amp;Selection</source>
        <translation>Ĝisdatigi Elekton</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1400"/>
        <source>&amp;Spelling...</source>
        <translation>Literumado...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1400"/>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1401"/>
        <source>Set &amp;Language...</source>
        <translation>Agordi Lingvon...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1403"/>
        <source>&amp;Timers...</source>
        <translation>Tempomezuriloj...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1404"/>
        <source>S&amp;ymbols...</source>
        <translation>Simboloj</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1405"/>
        <source>&amp;Daily Progress</source>
        <translation>Ĉiutaga Progreso</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1408"/>
        <source>&amp;Settings</source>
        <translation>Agordoj</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1409"/>
        <source>Show &amp;Toolbar</source>
        <translation>Montri Ilobreton</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1414"/>
        <source>Show &amp;Menu Icons</source>
        <translation>Montri Menuajn Bildsimbolojn</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1420"/>
        <source>F&amp;ocused Text</source>
        <translation>Fokusita Teksto</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1422"/>
        <source>&amp;Fullscreen</source>
        <translation>Tutekrane</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1422"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1424"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1428"/>
        <source>M&amp;inimize</source>
        <translation>Plejetigi</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1428"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1430"/>
        <source>&amp;Themes...</source>
        <translation>Etosoj...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1433"/>
        <source>&amp;Preferences...</source>
        <translation>Agordoj...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1439"/>
        <source>Focus Off</source>
        <translation>Ne Fokusi</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1441"/>
        <source>Focus One Line</source>
        <translation>Unulinea Fokuso</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1443"/>
        <source>Focus Three Lines</source>
        <translation>Trilinea Fokuso</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1444"/>
        <source>&amp;Paragraph</source>
        <translation>Alineo</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1445"/>
        <source>Focus Paragraph</source>
        <translation>Fokusi Alineon</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1454"/>
        <source>Ctrl+Shift+`</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1459"/>
        <source>&amp;Help</source>
        <translation>Helpo</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1432"/>
        <source>Application &amp;Language...</source>
        <translation>Lingvo de la Aplikaĵo...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="400"/>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Kelkaj dosieroj ne estis subtenitaj kaj ne povis malfermiĝi.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1438"/>
        <source>&amp;Off</source>
        <translation>Ne</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1440"/>
        <source>One &amp;Line</source>
        <translation>Unu Lineo</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1442"/>
        <source>&amp;Three Lines</source>
        <translation>Tri Lineo</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1460"/>
        <source>&amp;About</source>
        <translation>Pri</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1468"/>
        <source>About &amp;Qt</source>
        <translation>Pri &amp;Qt</translation>
    </message>
</context>
</TS>
